/// <reference types="lodash" />
import * as IGlobalStore from './GlobalStoreTypes';
export declare const isPrimitive: <T>(value: T) => boolean;
/**
* This is a class to create global-store objects
* @template IState
* @param {IState} state - Initial state,
* @template IActions
* @param {IActions} actions - An specific api to restrict the use of the state,
* this will disable the default return of the state-setter of the hook, and instead will return the API
* @param {string} persistStoreAs - A name if you want to persist the state of the store in localstorage
* */
export declare class GlobalStore<IState, IActions extends IGlobalStore.IActionCollection<IState> | null = null> implements IGlobalStore.IGlobalState<IState, IActions> {
    protected state: IState;
    protected actions: IActions;
    protected persistStoreAs: string | null;
    protected subscribers: IGlobalStore.StateSetter<IState>[];
    get isPersistStore(): boolean;
    constructor(state: IState, actions?: IActions, persistStoreAs?: string | null);
    private storedStateItem;
    protected formatItemFromStore<T>(obj: T): any;
    protected getStoreItem(): IState;
    protected formatToStore<T>(obj: T): any;
    protected setStoreItem(): void;
    protected getPersistStoreValue: () => IState;
    protected getStateCopy: () => IState;
    /**
     * Returns a global hook that will share information across components by subscribing them to a specific store.
     * @return [currentState, GlobalState.IHookResult<IState, IActions, IApi>]
     */
    getHook: <IApi extends IGlobalStore.ActionCollectionResult<IActions> | null = IActions extends null ? null : IGlobalStore.ActionCollectionResult<IActions>>() => () => [IState, IGlobalStore.IHookResult<IState, IActions, IApi>];
    /**
     * This is an access to the subscribers queue and to the current state of a specific store...
     * THIS IS NOT A REACT-HOOK, so you could use it everywhere example other hooks, and services.
     * @return [currentState, GlobalState.IHookResult<IState, IActions, IApi>]
     */
    getHookDecoupled: <IApi extends IGlobalStore.ActionCollectionResult<IActions> | null = IActions extends null ? null : IGlobalStore.ActionCollectionResult<IActions>>() => () => [() => IState, IGlobalStore.IHookResult<IState, IActions, IApi>];
    private _stateOrchestrator;
    protected get stateOrchestrator(): IGlobalStore.StateSetter<IState> | IGlobalStore.ActionCollectionResult<IActions>;
    /**
     **  [subscriber-update-callback, hook, newState]
     */
    protected static batchedUpdates: [() => void, object, object][];
    protected globalSetter: (setter: Partial<IState> | ((state: IState) => Partial<IState>), callback: () => void) => void;
    protected globalSetterAsync: (setter: Partial<IState> | ((state: IState) => Partial<IState>)) => Promise<void>;
    protected globalSetterToPersistStoreAsync: (setter: Partial<IState> | ((state: IState) => Partial<IState>)) => Promise<void>;
    static ExecutePendingBatches: import("lodash").DebouncedFunc<(callback: () => void) => void>;
    protected getActions: <IApi extends IGlobalStore.ActionCollectionResult<IGlobalStore.IActionCollection<IState>>>() => IApi;
}
export default GlobalStore;
//# sourceMappingURL=GlobalStore.d.ts.map